onTap property

VoidCallback? onTap
final

Called when the pill is tapped.

This is called regardless of whether the pill is editable. If editable is true and value is not null, editing mode will also be triggered.

Implementation

final VoidCallback? onTap;