showCheckIcon property

bool showCheckIcon
final

Whether to show a check icon when the pill is selected.

When true and selected is true, a check icon is displayed at the leading edge of the pill. The icon color matches the label color.

Defaults to false.

Implementation

final bool showCheckIcon;