style property

PillStyle? style
final

The style configuration for this pill.

If null, the pill uses the default black border on transparent background. Use PillStyles for predefined color schemes, or create a custom PillStyle.

Implementation

final PillStyle? style;