summary property
A shorter version of the value to be displayed when the pill is collapsed.
If provided and the pill is not expanded, this text is shown instead of the value. This is useful for long text that should be summarized initially.
Implementation
final String? summary;