value property

dynamic value
final

The content displayed on the right side of the pill.

Can be a String (rendered as styled text), a Widget, or null. If null, the pill displays only the label. If a String and editable is true, tapping the pill enables inline editing. If a Widget, editing is disabled regardless of the editable flag.

Implementation

final dynamic value;