dividerColor property
The color of the divider between label and value.
Defaults to the border color if not specified.
Implementation
final Color? dividerColor;
The color of the divider between label and value.
Defaults to the border color if not specified.
final Color? dividerColor;