fontSize property
The font size for both label and value text.
Defaults to the theme's body medium text size.
Implementation
final double? fontSize;
The font size for both label and value text.
Defaults to the theme's body medium text size.
final double? fontSize;