Pill class

A pill-shaped widget that displays a label and an optional editable value.

The Pill widget is designed to show a tag or property in a compact form. It consists of a label on the left and an optional value on the right.

If value is provided, the pill displays a separator line between the label and the value. When the user taps on the pill, it switches to an editing mode (if value is not null), allowing the user to modify the text.

When editing is finished (by submitting or losing focus), the onValueChanged callback is triggered with the new value.

Inheritance

Constructors

Pill({Key? key, required String label, String? value, ValueChanged<String>? onValueChanged})
Creates a Pill widget.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
label String
The text displayed on the left side of the pill.
final
onValueChanged ValueChanged<String>?
Called when the user finishes editing the value.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String?
The text displayed on the right side of the pill.
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<Pill>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited