leading property
A widget displayed before the label inside the pill border.
When both leading and showCheckIcon are provided, the check icon renders first, then the leading widget.
Implementation
final Widget? leading;
A widget displayed before the label inside the pill border.
When both leading and showCheckIcon are provided, the check icon renders first, then the leading widget.
final Widget? leading;