style property
The style configuration for this pill.
If null, the pill uses the default black border on transparent background. Use PillStyles for predefined color schemes, or create a custom PillStyle.
Implementation
final PillStyle? style;
The style configuration for this pill.
If null, the pill uses the default black border on transparent background. Use PillStyles for predefined color schemes, or create a custom PillStyle.
final PillStyle? style;